@@ -138,7 +138,10 @@ def handle_logs(options, config):
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/builds/{options.uid}",
     )
-    if ret.status_code != 200:
+    if ret.status_code == 404:
+        print(f"warning: {colors.red}Log unavailable{colors.reset}")
+        return 0
+    elif ret.status_code != 200:
         raise NotImplementedError()
 
     # TODO: add a wrapper around requests.get
