@@ -7,7 +7,7 @@ from tuxsuite.requests import get
 def download(build, output):
     output = Path(output)
     output.mkdir(exist_ok=True)
-    build_dir = output / build.build_key
+    build_dir = output / build.uid
     build_dir.mkdir(exist_ok=True)
     files = get(build.build_data + "?export=json").json()
     # TODO parallelize?
